kill_client_blocking

Function kill_client_blocking 

pub fn kill_client_blocking(
    address: ClientId,
    timeout: Duration,
) -> Result<bool>
Sends a close window request to hyprland and waits for the client to be killed

Returns true if the client was killed successfully, false if close was interrupted